summaryrefslogtreecommitdiff
path: root/src/Text/Pandoc/ODT.hs
diff options
context:
space:
mode:
authorfiddlosopher <fiddlosopher@788f1e2b-df1e-0410-8736-df70ead52e1b>2009-12-31 22:40:59 +0000
committerfiddlosopher <fiddlosopher@788f1e2b-df1e-0410-8736-df70ead52e1b>2009-12-31 22:40:59 +0000
commited1535de108594db53b0fd86724b2dff8165ae8c (patch)
tree6d0bfa76da87c7e73bfb96165e7f1b1ae6b05f64 /src/Text/Pandoc/ODT.hs
parentbdd448ea2cf41324a63bd09771b5ac553e65f540 (diff)
Added --reference-odt option.
This allows the user to customized the styles used in pandoc-generated ODTs. The user may also put a default reference.odt in the ~/.pandoc directory. We have removed the old data/odt directory and replaced it with a reference.odt. git-svn-id: https://pandoc.googlecode.com/svn/trunk@1760 788f1e2b-df1e-0410-8736-df70ead52e1b
Diffstat (limited to 'src/Text/Pandoc/ODT.hs')
-rw-r--r--src/Text/Pandoc/ODT.hs29
1 files changed, 16 insertions, 13 deletions
diff --git a/src/Text/Pandoc/ODT.hs b/src/Text/Pandoc/ODT.hs
index 01390cbbf..7b5fe9daa 100644
--- a/src/Text/Pandoc/ODT.hs
+++ b/src/Text/Pandoc/ODT.hs
@@ -37,24 +37,27 @@ import Codec.Archive.Zip
import Control.Applicative ( (<$>) )
import Text.ParserCombinators.Parsec
import System.Time
-import Text.Pandoc.Shared ( inDirectory )
import Paths_pandoc ( getDataFileName )
import System.Directory
+import Control.Monad (liftM)
-- | Produce an ODT file from OpenDocument XML.
-saveOpenDocumentAsODT :: FilePath -- ^ Pathname of ODT file to be produced.
- -> FilePath -- ^ Relative directory of source file.
- -> String -- ^ OpenDocument XML contents.
+saveOpenDocumentAsODT :: FilePath -- ^ Pathname of ODT file to be produced.
+ -> FilePath -- ^ Relative directory of source file.
+ -> Maybe FilePath -- ^ Path specified by --reference-odt
+ -> String -- ^ OpenDocument XML contents.
-> IO ()
-saveOpenDocumentAsODT destinationODTPath sourceDirRelative xml = do
- userDir <- getAppUserDataDirectory "pandoc"
- userOdtExists <- doesFileExist $
- userDir </> "data" </> "odt" </> "styles.xml"
- refArchivePath <- if userOdtExists
- then return $ userDir </> "data" </> "odt"
- else getDataFileName $ "data" </> "odt"
- refArchive <- inDirectory refArchivePath $
- addFilesToArchive [OptRecursive] emptyArchive ["."]
+saveOpenDocumentAsODT destinationODTPath sourceDirRelative mbRefOdt xml = do
+ refArchive <- liftM toArchive $
+ case mbRefOdt of
+ Just f -> B.readFile f
+ Nothing -> do
+ userDataDir <- getAppUserDataDirectory "pandoc"
+ let userRefOdt = userDataDir </> "reference.odt"
+ userRefOdtExists <- doesFileExist userRefOdt
+ if userRefOdtExists
+ then B.readFile userRefOdt
+ else getDataFileName "reference.odt" >>= B.readFile
-- handle pictures
let (newContents, pics) =
case runParser pPictures [] "OpenDocument XML contents" xml of